@@ -1,8 +1,8 @@
-/* $Id: fxmesa.h,v 1.6 1997/06/26 14:28:42 brianp Exp $ */
+/* $Id: fxmesa.h,v 1.10 1997/09/18 23:09:49 brianp Exp $ */
 
 /*
  * Mesa 3-D graphics library
- * Version:  2.3
+ * Version:  2.4
  * Copyright (C) 1995-1997  Brian Paul
  *
  * This library is free software; you can redistribute it and/or
@@ -23,6 +23,18 @@
 
 /*
  * $Log: fxmesa.h,v $
+ * Revision 1.10  1997/09/18 23:09:49  brianp
+ * set minor version number to 4
+ *
+ * Revision 1.9  1997/08/24 17:37:22  brianp
+ * added fxMesaTextureUsePalette()
+ *
+ * Revision 1.8  1997/08/19 02:35:45  brianp
+ * added fxQueryHardware() and fxCloseHardware()
+ *
+ * Revision 1.7  1997/07/08 02:15:19  brianp
+ * removed USE_GLIDE_FULLSCREEN hack, no longer needed with Glide 2.3.1
+ *
  * Revision 1.6  1997/06/26 14:28:42  brianp
  * set USE_GLIDE_FULLSCREEN by testing for __WIN32__
  *
@@ -47,6 +59,8 @@
 
 /*
  * FXMesa - 3Dfx Glide driver for Mesa.  Contributed by David Bucciarelli
+ *
+ * NOTE: This version requires Glide 2.3 or later.
  */
 
 
@@ -63,18 +77,7 @@ extern "C" {
 
 
 #define FXMESA_MAJOR_VERSION 2
-#define FXMESA_MINOR_VERSION 3
-
-
-/*
- * 0 = 3Dfx in a window (Rush chipset)
- * 1 = 3Dfx full-screen (Voodoo chipset)
- */
-#ifdef __WIN32__
-#define USE_GLIDE_FULLSCREEN 0
-#else
-#define USE_GLIDE_FULLSCREEN 1
-#endif
+#define FXMESA_MINOR_VERSION 4
 
 
 /*
@@ -111,6 +114,14 @@ extern void fxMesaSwapBuffers(void);
 extern void fxMesaSetNearFar(GLfloat nearVal, GLfloat farVal);
 
 
+extern int fxQueryHardware(void);
+
+extern int fxCloseHardware(void);
+
+
+extern void fxMesaTextureUsePalette(GLboolean state);
+
+
 #ifdef __cplusplus
 }
 #endif
