@@ -1,8 +1,8 @@
-/* $Id: polytest.c,v 1.3 1997/05/28 02:29:38 brianp Exp $ */
+/* $Id: polytest.c,v 1.4 1997/07/24 01:28:44 brianp Exp $ */
 
 /*
  * Mesa 3-D graphics library
- * Version:  2.3
+ * Version:  2.4
  * Copyright (C) 1995-1997  Brian Paul
  *
  * This library is free software; you can redistribute it and/or
@@ -23,6 +23,9 @@
 
 /*
  * $Log: polytest.c,v $
+ * Revision 1.4  1997/07/24 01:28:44  brianp
+ * changed precompiled header symbol from PCH to PC_HEADER
+ *
  * Revision 1.3  1997/05/28 02:29:38  brianp
  * added support for precompiled headers (PCH), inserted APIENTRY keyword
  *
@@ -41,7 +44,7 @@
  */
 
 
-#ifdef PCH
+#ifdef PC_HEADER
 #include "all.h"
 #else
 #include <math.h>
