@@ -1,8 +1,8 @@
-/* $Id: clip.c,v 1.13 1997/05/28 03:23:48 brianp Exp $ */
+/* $Id: clip.c,v 1.14 1997/07/24 01:24:45 brianp Exp $ */
 
 /*
  * Mesa 3-D graphics library
- * Version:  2.3
+ * Version:  2.4
  * Copyright (C) 1995-1997  Brian Paul
  *
  * This library is free software; you can redistribute it and/or
@@ -23,6 +23,9 @@
 
 /*
  * $Log: clip.c,v $
+ * Revision 1.14  1997/07/24 01:24:45  brianp
+ * changed precompiled header symbol from PCH to PC_HEADER
+ *
  * Revision 1.13  1997/05/28 03:23:48  brianp
  * added precompiled header (PCH) support
  *
@@ -66,7 +69,7 @@
  */
 
 
-#ifdef PCH
+#ifdef PC_HEADER
 #include "all.h"
 #else
 #include <string.h>
