@@ -1,8 +1,8 @@
-/* $Id: context.c,v 1.48 1997/06/20 02:19:49 brianp Exp $ */
+/* $Id: context.c,v 1.51 1997/09/17 01:39:11 brianp Exp $ */
 
 /*
  * Mesa 3-D graphics library
- * Version:  2.3
+ * Version:  2.4
  * Copyright (C) 1995-1997  Brian Paul
  *
  * This library is free software; you can redistribute it and/or
@@ -23,6 +23,15 @@
 
 /*
  * $Log: context.c,v $
+ * Revision 1.51  1997/09/17 01:39:11  brianp
+ * added update_clipmask() function from Michael Pichler
+ *
+ * Revision 1.50  1997/09/10 00:29:19  brianp
+ * set all NewState flags in gl_ResizeBuffersMESA() (Miklos Fazekas)
+ *
+ * Revision 1.49  1997/07/24 01:24:45  brianp
+ * changed precompiled header symbol from PCH to PC_HEADER
+ *
  * Revision 1.48  1997/06/20 02:19:49  brianp
  * replaced Current.IntColor with Current.ByteColor
  *
@@ -179,7 +188,7 @@
  */
 
 
-#ifdef PCH
+#ifdef PC_HEADER
 #include "all.h"
 #else
 #include <assert.h>
@@ -1560,6 +1569,8 @@ void gl_ResizeBuffersMESA( GLcontext *ctx )
    GLint newsize;
    GLuint buf_width, buf_height;
    
+   ctx->NewState |= NEW_ALL;   /* just to be safe */
+
    /* ask device driver for size of output buffer */
    (*ctx->Driver.GetBufferSize)( ctx, &buf_width, &buf_height );
 
@@ -1707,7 +1718,7 @@ static void update_pixel_masking( GLcontext *ctx )
 
 
 /*
- * Recompute the value of ctx->RasterMask, ctx->ClipMask, etc. according to
+ * Recompute the value of ctx->RasterMask, etc. according to
  * the current context.
  */
 static void update_rasterflags( GLcontext *ctx )
@@ -1747,7 +1758,15 @@ static void update_rasterflags( GLcontext *ctx )
    else if (!ctx->Visual->RGBAflag && ctx->Color.IndexMask==0) {
       ctx->RasterMask |= NO_DRAW_BIT;
    }
+}
 
+
+/*
+ * Recompute the value of ctx->ClipMask according to the current context.
+ * ClipMask depends on Texturing and Lighting.
+ */
+static void update_clipmask(GLcontext *ctx)
+{
    /* Recompute ClipMask (what has to be interpolated when clipping) */
    ctx->ClipMask = 0;
    if (ctx->Texture.Enabled) {
@@ -1787,6 +1806,10 @@ void gl_update_state( GLcontext *ctx )
       }
    }
 
+   if (ctx->NewState & (NEW_RASTER_OPS | NEW_LIGHTING)) {
+      update_clipmask(ctx);
+   }
+
    if (ctx->NewState & NEW_LIGHTING) {
       gl_update_lighting(ctx);
       gl_set_color_function(ctx);
