@@ -1,8 +1,8 @@
-/* $Id: drawpix.c,v 1.12 1997/06/20 02:18:23 brianp Exp $ */
+/* $Id: drawpix.c,v 1.15 1997/08/26 02:10:11 brianp Exp $ */
 
 /*
  * Mesa 3-D graphics library
- * Version:  2.3
+ * Version:  2.4
  * Copyright (C) 1995-1997  Brian Paul
  *
  * This library is free software; you can redistribute it and/or
@@ -23,6 +23,15 @@
 
 /*
  * $Log: drawpix.c,v $
+ * Revision 1.15  1997/08/26 02:10:11  brianp
+ * another bug fix related to glPixelStore()
+ *
+ * Revision 1.14  1997/08/24 02:31:23  brianp
+ * bug fix: glPixelStore() params weren't ignored during display list execute
+ *
+ * Revision 1.13  1997/07/24 01:25:01  brianp
+ * changed precompiled header symbol from PCH to PC_HEADER
+ *
  * Revision 1.12  1997/06/20 02:18:23  brianp
  * replaced Current.IntColor with Current.ByteColor
  *
@@ -62,7 +71,7 @@
  */
 
 
-#ifdef PCH
+#ifdef PC_HEADER
 #include "all.h"
 #else
 #include <stdlib.h>
@@ -1025,7 +1034,7 @@ void gl_DrawPixels( GLcontext* ctx, GLsizei width, GLsizei height,
 
    if (format==GL_RGB && type==GL_UNSIGNED_BYTE && ctx->FastDrawPixels
        && !ctx->CompileFlag && ctx->RenderMode==GL_RENDER
-       && ctx->RasterMask==0) {
+       && ctx->RasterMask==0 && ctx->CallDepth==0) {
       /* optimized path */
       if (quickdraw_rgb( ctx, width, height, pixels )) {
          /* success */
@@ -1034,10 +1043,19 @@ void gl_DrawPixels( GLcontext* ctx, GLsizei width, GLsizei height,
    }
 
    /* take the general path */
-   image = gl_unpack_pixels( ctx, width, height, format, type, pixels );
-   if (!image) {
-      gl_error( ctx, GL_OUT_OF_MEMORY, "glDrawPixels" );
-      return;
+
+   /* THIS IS A REAL HACK - FIX IN MESA 2.5
+    * If we're inside glCallList then we don't have to unpack the pixels again.
+    */
+   if (ctx->CallDepth == 0) {
+      image = gl_unpack_pixels( ctx, width, height, format, type, pixels );
+      if (!image) {
+         gl_error( ctx, GL_OUT_OF_MEMORY, "glDrawPixels" );
+         return;
+      }
+   }
+   else {
+      image = (GLvoid *) pixels;
    }
 
    if (ctx->CompileFlag) {
@@ -1047,7 +1065,8 @@ void gl_DrawPixels( GLcontext* ctx, GLsizei width, GLsizei height,
       drawpixels( ctx, width, height, format, type, image );
       if (!ctx->CompileFlag) {
          /* may discard unpacked image now */
-         free( image );
+         if (image!=pixels)
+            free( image );
       }
    }
 }
