@@ -1,8 +1,8 @@
-/* $Id: fakeglx.c,v 1.18 1997/06/20 02:26:36 brianp Exp $ */
+/* $Id: fakeglx.c,v 1.20 1997/08/13 01:52:18 brianp Exp $ */
 
 /*
  * Mesa 3-D graphics library
- * Version:  2.3
+ * Version:  2.4
  * Copyright (C) 1995-1997  Brian Paul
  *
  * This library is free software; you can redistribute it and/or
@@ -23,6 +23,15 @@
 
 /*
  * $Log: fakeglx.c,v $
+ * Revision 1.20  1997/08/13 01:52:18  brianp
+ * don't look for visuals deeper than 24 bits
+ * fixed problem in glXSwapBuffers (Stephane Rehel)
+ * glXReleaseBuffersMESA() now takes a GLXDrawable instead of a Window
+ * updated version string to 2.4
+ *
+ * Revision 1.19  1997/07/24 01:07:05  brianp
+ * small change to error handling in glXMakeCurrent()
+ *
  * Revision 1.18  1997/06/20 02:26:36  brianp
  * removed unused bitcount() function
  *
@@ -540,7 +549,7 @@ static XVisualInfo *choose_x_visual( Display *dpy, int screen,
             }
             if (min_depth==0) {
                /* start with shallowest */
-               for (depth=0;depth<=32;depth++) {
+               for (depth=0;depth<=24;depth++) {
                   if (visclass==TrueColor && depth==8 && !hp_cr_maps) {
                      /* Special case:  try to get 8-bit PseudoColor before */
                      /* 8-bit TrueColor */
@@ -557,7 +566,7 @@ static XVisualInfo *choose_x_visual( Display *dpy, int screen,
             }
             else {
                /* start with deepest */
-               for (depth=32;depth>=min_depth;depth--) {
+               for (depth=24;depth>=min_depth;depth--) {
                   if (visclass==TrueColor && depth==8 && !hp_cr_maps) {
                      /* Special case:  try to get 8-bit PseudoColor before */
                      /* 8-bit TrueColor */
@@ -587,7 +596,7 @@ static XVisualInfo *choose_x_visual( Display *dpy, int screen,
          }
          if (min_depth==0) {
             /* start with shallowest */
-            for (depth=0;depth<=32;depth++) {
+            for (depth=0;depth<=24;depth++) {
                vis = get_visual( dpy, screen, depth, visclass );
                if (vis) {
                   return vis;
@@ -596,7 +605,7 @@ static XVisualInfo *choose_x_visual( Display *dpy, int screen,
          }
          else {
             /* start with deepest */
-            for (depth=32;depth>=min_depth;depth--) {
+            for (depth=24;depth>=min_depth;depth--) {
                vis = get_visual( dpy, screen, depth, visclass );
                if (vis) {
                   return vis;
@@ -997,8 +1006,8 @@ Bool Fake_glXMakeCurrent( Display *dpy, GLXDrawable drawable, GLXContext ctx )
          /* drawable must be a new window! */
          buffer = XMesaCreateWindowBuffer( ctx->xm_visual, drawable );
          if (!buffer) {
-            /* If this happens, increase MAX_BUFFERS and recompile */
-            fprintf(stderr,"Mesa GLX error: too many windows!\n");
+            /* Out of memory, hit MAX_BUFFERS limit, or bad visual/drawable */
+            /* combination! */
             return False;
          }
       }
@@ -1119,22 +1128,12 @@ Bool Fake_glXIsDirect( Display *dpy, GLXContext ctx )
 
 void Fake_glXSwapBuffers( Display *dpy, GLXDrawable drawable )
 {
-   static GLXDrawable prev_drawable = 0;
-   static XMesaBuffer prev_buffer = 0;
-
-   if (drawable==prev_drawable) {
-      XMesaSwapBuffers( prev_buffer );
-      return;
+   XMesaBuffer buffer = XMesaFindBuffer( dpy, drawable );
+   if (buffer) {
+      XMesaSwapBuffers(buffer);
    }
-
-   prev_drawable = drawable;
-   prev_buffer = XMesaFindBuffer( dpy, drawable );
-   if (prev_buffer) {
-      XMesaSwapBuffers( prev_buffer );
-   }
-   else {
-      fprintf( stderr,
-	  "Warning: glXSwapBuffers drawable doesn't match current context\n");
+   else if (getenv("MESA_DEBUG")) {
+      fprintf(stderr, "Mesa Warning: glXSwapBuffers: invalid drawable\n");
    }
 }
 
@@ -1347,7 +1346,7 @@ const char *Fake_glXQueryServerString( Display *dpy, int screen, int name )
 {
    static char *extensions = EXTENSIONS;
    static char *vendor = "Brian Paul";
-   static char *version = "1.1 Mesa 2.3";
+   static char *version = "1.1 Mesa 2.4";
 
    switch (name) {
       case GLX_EXTENSIONS:
@@ -1368,7 +1367,7 @@ const char *Fake_glXGetClientString( Display *dpy, int name )
 {
    static char *extensions = EXTENSIONS;
    static char *vendor = "Brian Paul";
-   static char *version = "1.1 Mesa 2.3";
+   static char *version = "1.1 Mesa 2.4";
 
    switch (name) {
       case GLX_EXTENSIONS:
@@ -1385,12 +1384,12 @@ const char *Fake_glXGetClientString( Display *dpy, int name )
 
 
 /*
- * Release the depth, stencil, accum buffers attached to a window prior
- * to destroying the window.
+ * Release the depth, stencil, accum buffers attached to a GLXDrawable
+ * (a window or pixmap) prior to destroying the GLXDrawable.
  */
-Bool Fake_glXReleaseBuffersMESA( Display *dpy, Window w )
+Bool Fake_glXReleaseBuffersMESA( Display *dpy, GLXDrawable d )
 {
-   XMesaBuffer b = XMesaFindBuffer(dpy, w);
+   XMesaBuffer b = XMesaFindBuffer(dpy, d);
    if (b) {
       XMesaDestroyBuffer(b);
       return True;
