@@ -1,8 +1,8 @@
-/* $Id: stencil.c,v 1.6 1997/05/28 03:26:29 brianp Exp $ */
+/* $Id: stencil.c,v 1.7 1997/07/24 01:21:56 brianp Exp $ */
 
 /*
  * Mesa 3-D graphics library
- * Version:  2.3
+ * Version:  2.4
  * Copyright (C) 1995-1997  Brian Paul
  *
  * This library is free software; you can redistribute it and/or
@@ -23,6 +23,9 @@
 
 /*
  * $Log: stencil.c,v $
+ * Revision 1.7  1997/07/24 01:21:56  brianp
+ * changed precompiled header symbol from PCH to PC_HEADER
+ *
  * Revision 1.6  1997/05/28 03:26:29  brianp
  * added precompiled header (PCH) support
  *
@@ -44,7 +47,7 @@
  */
 
 
-#ifdef PCH
+#ifdef PC_HEADER
 #include "all.h"
 #else
 #include <stdlib.h>
