@@ -1,8 +1,8 @@
-/* $Id: texstate.c,v 1.4 1997/05/28 03:26:49 brianp Exp $ */
+/* $Id: texstate.c,v 1.5 1997/07/24 01:25:34 brianp Exp $ */
 
 /*
  * Mesa 3-D graphics library
- * Version:  2.3
+ * Version:  2.4
  * Copyright (C) 1995-1997  Brian Paul
  *
  * This library is free software; you can redistribute it and/or
@@ -23,6 +23,9 @@
 
 /*
  * $Log: texstate.c,v $
+ * Revision 1.5  1997/07/24 01:25:34  brianp
+ * changed precompiled header symbol from PCH to PC_HEADER
+ *
  * Revision 1.4  1997/05/28 03:26:49  brianp
  * added precompiled header (PCH) support
  *
@@ -38,7 +41,7 @@
  */
 
 
-#ifdef PCH
+#ifdef PC_HEADER
 #include "all.h"
 #else
 #include "context.h"
