@@ -1,8 +1,8 @@
-/* $Id: texture.c,v 1.28 1997/05/28 03:26:49 brianp Exp $ */
+/* $Id: texture.c,v 1.32 1997/08/14 01:03:12 brianp Exp $ */
 
 /*
  * Mesa 3-D graphics library
- * Version:  2.3
+ * Version:  2.4
  * Copyright (C) 1995-1997  Brian Paul
  *
  * This library is free software; you can redistribute it and/or
@@ -23,6 +23,18 @@
 
 /*
  * $Log: texture.c,v $
+ * Revision 1.32  1997/08/14 01:03:12  brianp
+ * fixed small bug in GL_SPHERE_MAP texgen (Petri Nordlund)
+ *
+ * Revision 1.31  1997/07/24 01:25:34  brianp
+ * changed precompiled header symbol from PCH to PC_HEADER
+ *
+ * Revision 1.30  1997/07/22 01:23:48  brianp
+ * fixed negative texture coord sampling problem (Magnus Lundin)
+ *
+ * Revision 1.29  1997/07/09 00:32:26  brianp
+ * fixed bug involving sampling and incomplete texture objects
+ *
  * Revision 1.28  1997/05/28 03:26:49  brianp
  * added precompiled header (PCH) support
  *
@@ -112,7 +124,7 @@
  */
 
 
-#ifdef PCH
+#ifdef PC_HEADER
 #include "all.h"
 #else
 #include <math.h>
@@ -190,12 +202,12 @@ void gl_texgen( GLcontext *ctx, GLint n,
                fx = u[0] - normal[i][0] * two_nu;
                fy = u[1] - normal[i][1] * two_nu;
                fz = u[2] - normal[i][2] * two_nu;
-               m = 2.0 * GL_SQRT( fx*fx + fy*fy + (fz+1.0)*(fz+1.0) );
-               if (m==0.0) {
-                  texcoord[i][0] = 0.0;
+               m = 2.0F * GL_SQRT( fx*fx + fy*fy + (fz+1.0)*(fz+1.0) );
+               if (m==0.0F) {
+                  texcoord[i][0] = 0.5F;
                }
                else {
-                  texcoord[i][0] = fx / m + 0.5;
+                  texcoord[i][0] = fx / m + 0.5F;
                }
             }
             break;
@@ -227,12 +239,12 @@ void gl_texgen( GLcontext *ctx, GLint n,
                fx = u[0] - normal[i][0] * two_nu;
                fy = u[1] - normal[i][1] * two_nu;
                fz = u[2] - normal[i][2] * two_nu;
-               m = 2.0 * GL_SQRT( fx*fx + fy*fy + (fz+1.0)*(fz+1.0) );
-               if (m==0.0) {
-                  texcoord[i][1] = 0.0;
+               m = 2.0F * GL_SQRT( fx*fx + fy*fy + (fz+1.0)*(fz+1.0) );
+               if (m==0.0F) {
+                  texcoord[i][1] = 0.5F;
                }
                else {
-                  texcoord[i][1] = fy / m + 0.5;
+                  texcoord[i][1] = fy / m + 0.5F;
                }
             }
             break;
@@ -362,6 +374,7 @@ static void sample_1d_nearest( const struct gl_texture_object *tObj,
       /* s limited to [0,1) */
       /* i limited to [0,width-1] */
       i = (GLint) (s * width);
+      if (s<0.0F)  i -= 1;
       i &= (width-1);
    }
    else {
@@ -760,6 +773,7 @@ static void sample_2d_nearest( const struct gl_texture_object *tObj,
       /* s limited to [0,1) */
       /* i limited to [0,width-1] */
       i = (GLint) (s * width);
+      if (s<0.0F)  i -= 1;
       i &= (width-1);
    }
    else {
@@ -775,6 +789,7 @@ static void sample_2d_nearest( const struct gl_texture_object *tObj,
       /* t limited to [0,1) */
       /* j limited to [0,height-1] */
       j = (GLint) (t * height);
+      if (t<0.0F)  j -= 1;
       j &= (height-1);
    }
    else {
@@ -1193,7 +1208,7 @@ static void opt_sample_rgba_2d( const struct gl_texture_object *tObj,
    ASSERT(tObj->WrapS==GL_REPEAT);
    ASSERT(tObj->WrapT==GL_REPEAT);
    ASSERT(img->Border==0);
-   ASSERT(img->Format==GL_RGB);
+   ASSERT(img->Format==GL_RGBA);
 
    for (k=0;k<n;k++) {
       GLint i = (GLint) (s[k] * width) & colMask;
@@ -1293,6 +1308,7 @@ static void sample_3d_nearest( const struct gl_texture_object *tObj,
       /* s limited to [0,1) */
       /* i limited to [0,width-1] */
       i = (GLint) (s * width);
+      if (s<0.0F)  i -= 1;
       i &= (width-1);
    }
    else {
@@ -1308,6 +1324,7 @@ static void sample_3d_nearest( const struct gl_texture_object *tObj,
       /* t limited to [0,1) */
       /* j limited to [0,height-1] */
       j = (GLint) (t * height);
+      if (t<0.0F)  j -= 1;
       j &= (height-1);
    }
    else {
@@ -1323,6 +1340,7 @@ static void sample_3d_nearest( const struct gl_texture_object *tObj,
       /* r limited to [0,1) */
       /* k limited to [0,depth-1] */
       k = (GLint) (r * depth);
+      if (r<0.0F)  k -= 1;
       k &= (depth-1);
    }
    else {
@@ -1756,16 +1774,6 @@ static void sample_lambda_3d( const struct gl_texture_object *tObj, GLuint n,
 /*                       Texture Sampling Setup                       */
 /**********************************************************************/
 
-static void sample_nop( const struct gl_texture_object *tObj, GLuint n,
-                        const GLfloat s[], const GLfloat t[],
-                        const GLfloat u[], const GLfloat lambda[],
-                        GLubyte r[], GLubyte g[],
-                        GLubyte b[],GLubyte a[] )
-{
-   /* do nothing */
-}
-
-
 
 /*
  * Setup the texture sampling function for this texture object.
@@ -1773,7 +1781,7 @@ static void sample_nop( const struct gl_texture_object *tObj, GLuint n,
 void gl_set_texture_sampler( struct gl_texture_object *t )
 {
    if (!t->Complete) {
-      t->SampleFunc = sample_nop;
+      t->SampleFunc = NULL;
    }
    else {
       GLboolean needLambda = (t->MinFilter != t->MagFilter);
