@@ -1,8 +1,8 @@
-/* $Id: vbxform.c,v 1.12 1997/06/20 02:57:59 brianp Exp $ */
+/* $Id: vbxform.c,v 1.15 1997/09/18 01:32:47 brianp Exp $ */
 
 /*
  * Mesa 3-D graphics library
- * Version:  2.3
+ * Version:  2.4
  * Copyright (C) 1995-1997  Brian Paul
  *
  * This library is free software; you can redistribute it and/or
@@ -23,6 +23,15 @@
 
 /*
  * $Log: vbxform.c,v $
+ * Revision 1.15  1997/09/18 01:32:47  brianp
+ * fixed divide by zero problem for "weird" projection matrices
+ *
+ * Revision 1.14  1997/09/10 00:28:11  brianp
+ * fixed an optimization bug in viewport_map_vertices()
+ *
+ * Revision 1.13  1997/07/24 01:25:27  brianp
+ * changed precompiled header symbol from PCH to PC_HEADER
+ *
  * Revision 1.12  1997/06/20 02:57:59  brianp
  * changed color components from GLfixed to GLubyte
  *
@@ -73,7 +82,7 @@
  */
 
 
-#ifdef PCH
+#ifdef PC_HEADER
 #include "all.h"
 #else
 #include <stdlib.h>
@@ -670,8 +679,9 @@ static void viewport_map_vertices( GLcontext *ctx,
    GLfloat ty = ctx->Viewport.Ty;
    GLfloat sz = ctx->Viewport.Sz;
    GLfloat tz = ctx->Viewport.Tz;
-   if (ctx->ProjectionMatrixType==MATRIX_ORTHO || 
-       ctx->ProjectionMatrixType==MATRIX_IDENTITY) {
+   if ((ctx->ProjectionMatrixType==MATRIX_ORTHO || 
+        ctx->ProjectionMatrixType==MATRIX_IDENTITY)
+       && ctx->ModelViewMatrixType!=MATRIX_GENERAL) {
       /* don't need to divide by W */
       if (clipMask) {
          /* one or more vertices are clipped */
@@ -700,11 +710,19 @@ static void viewport_map_vertices( GLcontext *ctx,
          /* one or more vertices are clipped */
          GLuint i;
          for (i=0;i<n;i++) {
-            if (clipMask[i]==0) {
-               GLfloat wInv = 1.0F / vClip[i][3];
-               vWin[i][0] = vClip[i][0] * wInv * sx + tx;
-               vWin[i][1] = vClip[i][1] * wInv * sy + ty;
-               vWin[i][2] = vClip[i][2] * wInv * sz + tz;
+            if (clipMask[i] == 0) {
+               if (vClip[i][3] != 0.0F) {
+                  GLfloat wInv = 1.0F / vClip[i][3];
+                  vWin[i][0] = vClip[i][0] * wInv * sx + tx;
+                  vWin[i][1] = vClip[i][1] * wInv * sy + ty;
+                  vWin[i][2] = vClip[i][2] * wInv * sz + tz;
+               }
+               else {
+                  /* Div by zero!  Can't set window coords to infinity, so...*/
+                  vWin[i][0] = 0.0F;
+                  vWin[i][1] = 0.0F;
+                  vWin[i][2] = 0.0F;
+               }
             }
          }
       }
@@ -712,10 +730,18 @@ static void viewport_map_vertices( GLcontext *ctx,
          /* no vertices are clipped */
          GLuint i;
          for (i=0;i<n;i++) {
-            GLfloat wInv = 1.0F / vClip[i][3];
-            vWin[i][0] = vClip[i][0] * wInv * sx + tx;
-            vWin[i][1] = vClip[i][1] * wInv * sy + ty;
-            vWin[i][2] = vClip[i][2] * wInv * sz + tz;
+            if (vClip[i][3] != 0.0F) {
+               GLfloat wInv = 1.0F / vClip[i][3];
+               vWin[i][0] = vClip[i][0] * wInv * sx + tx;
+               vWin[i][1] = vClip[i][1] * wInv * sy + ty;
+               vWin[i][2] = vClip[i][2] * wInv * sz + tz;
+            }
+            else {
+               /* Divide by zero!  Can't set window coords to infinity, so...*/
+               vWin[i][0] = 0.0F;
+               vWin[i][1] = 0.0F;
+               vWin[i][2] = 0.0F;
+            }
          }
       }
    }
