@@ -1,8 +1,8 @@
-/* $Id: xmesa1.c,v 1.28 1997/06/20 02:54:37 brianp Exp $ */
+/* $Id: xmesa1.c,v 1.37 1997/08/26 02:08:42 brianp Exp $ */
 
 /*
  * Mesa 3-D graphics library
- * Version:  2.3
+ * Version:  2.4
  * Copyright (C) 1995-1997  Brian Paul
  *
  * This library is free software; you can redistribute it and/or
@@ -23,6 +23,33 @@
 
 /*
  * $Log: xmesa1.c,v $
+ * Revision 1.37  1997/08/26 02:08:42  brianp
+ * replaced MESA_FX_WINDOW/FULLSCREEN env vars with MESA_GLX_FX
+ *
+ * Revision 1.36  1997/08/14 01:22:18  brianp
+ * renamed environment vars: MESA_FX_WINDOW and MESA_FX_FULLSCREEN
+ *
+ * Revision 1.35  1997/08/13 02:06:03  brianp
+ * incorporated David Bucciarelli's v0.18 changes
+ *
+ * Revision 1.34  1997/08/11 01:23:41  brianp
+ * added a pointer cast
+ *
+ * Revision 1.33  1997/08/02 16:40:13  brianp
+ * removed unused FXhack variable
+ *
+ * Revision 1.32  1997/07/24 00:59:10  brianp
+ * implemented FXHACK (3Dfx rendering copied into X window)
+ *
+ * Revision 1.31  1997/07/18 03:15:44  brianp
+ * added some new assertions and error checking
+ *
+ * Revision 1.30  1997/07/11 23:11:40  brianp
+ * added NULL testing to XMesaFlush per Matthew Rees.  Bumped version to 2.4
+ *
+ * Revision 1.29  1997/07/11 23:07:55  brianp
+ * added XMesaGetDepthBuffer() function (Randy Frank)
+ *
  * Revision 1.28  1997/06/20 02:54:37  brianp
  * hopefully fixed a bug in XMesaMakeCurrent() involving reallocated memory
  *
@@ -147,6 +174,7 @@
 
 
 #include <assert.h>
+#include <ctype.h>
 #include <math.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -165,6 +193,12 @@
 #include "matrix.h"
 #include "types.h"
 
+#ifdef FX
+#include "GL/fxmesa.h"
+#define FX_WIDTH 640
+#define FX_HEIGHT 480
+#endif
+
 
 /*
  * Current X/Mesa context pointer:
@@ -791,7 +825,9 @@ static GLboolean setup_grayscale( XMesaVisual v, XMesaBuffer buffer,
                buffer->num_alloced++;
             }
 
+            assert(gray < 576);
             buffer->color_table[gray] = xcol.pixel;
+            assert(xcol.pixel < 65536);
             buffer->pixel_to_r[xcol.pixel] = gray * 30 / 100;
             buffer->pixel_to_g[xcol.pixel] = gray * 59 / 100;
             buffer->pixel_to_b[xcol.pixel] = gray * 11 / 100;
@@ -875,7 +911,9 @@ static GLboolean setup_dithered_color( XMesaVisual v, XMesaBuffer buffer,
                      buffer->num_alloced++;
                   }
                   i = _MIX( r, g, b );
+                  assert(i < 576);
                   buffer->color_table[i] = xcol.pixel;
+                  assert(xcol.pixel < 65536);
                   buffer->pixel_to_r[xcol.pixel] = r * 255 / (_R-1);
                   buffer->pixel_to_g[xcol.pixel] = g * 255 / (_G-1);
                   buffer->pixel_to_b[xcol.pixel] = b * 255 / (_B-1);
@@ -1096,7 +1134,7 @@ static void setup_monochrome( XMesaVisual v )
  * When a context is "made current" for the first time, we can finally
  * finish initializing the context's visual and buffer information.
  * Input:  v - the XMesaVisual to initialize
- *         b - the XMesaBuffer to initialize
+ *         b - the XMesaBuffer to initialize (may be NULL)
  *         rgb_flag - TRUE = RGBA mode, FALSE = color index mode
  *         window - the window/pixmap we're rendering into
  *         cmap - the colormap associated with the window/pixmap
@@ -1110,6 +1148,10 @@ static GLboolean initialize_visual_and_buffer( XMesaVisual v,
 {
    XGCValues gcvalues;
 
+   if (b) {
+      assert(b->xm_visual == v);
+   }
+
    if (rgb_flag==GL_FALSE) {
       /* COLOR-INDEXED WINDOW:
        * Even if the visual is TrueColor or DirectColor we treat it as
@@ -1330,7 +1372,7 @@ XMesaVisual XMesaCreateVisual( Display *display,
     * the struct but we may need some of the information contained in it
     * at a later time.
     */
-   v->visinfo = malloc(sizeof(*visinfo));
+   v->visinfo = (XVisualInfo *) malloc(sizeof(*visinfo));
    if(!v->visinfo) {
       free(v);
       return NULL;
@@ -1428,6 +1470,7 @@ void XMesaDestroyVisual( XMesaVisual v )
 XMesaContext XMesaCreateContext( XMesaVisual v, XMesaContext share_list )
 {
    XMesaContext c;
+   char *fxEnvVar;
 
    c = (XMesaContext) calloc( 1, sizeof(struct xmesa_context) );
    if (!c) {
@@ -1456,6 +1499,34 @@ XMesaContext XMesaCreateContext( XMesaVisual v, XMesaContext share_list )
 
    c->gl_ctx->Driver.UpdateState = xmesa_setup_DD_pointers;
 
+#ifdef FX
+   fxEnvVar = getenv("MESA_GLX_FX");
+   if (fxEnvVar) {
+      if (v->undithered_pf==PF_5R6G5B && tolower(fxEnvVar[0])=='w') {
+         /* Window rendering */
+         int attribs[] = {
+            FXMESA_DEPTH_SIZE, 1,
+            FXMESA_NONE
+         };
+
+         c->FXctx = fxMesaCreateBestContext(0, FX_WIDTH, FX_HEIGHT, attribs);
+         c->FXhack = c->FXctx ? GL_TRUE : GL_FALSE;
+      }
+      else if (tolower(fxEnvVar[0])=='f') {
+         /* Full-screen rendering */
+         int attribs[] = {
+            FXMESA_DOUBLEBUFFER,
+            FXMESA_DEPTH_SIZE, 1,
+            FXMESA_NONE
+         };
+
+         c->FXctx = fxMesaCreateBestContext(0, FX_WIDTH, FX_HEIGHT, attribs);
+         c->FXuse = c->FXctx ? GL_TRUE : GL_FALSE;
+         c->FXhack = GL_FALSE;
+      }
+   }
+#endif
+
    return c;
 }
 
@@ -1464,6 +1535,10 @@ XMesaContext XMesaCreateContext( XMesaVisual v, XMesaContext share_list )
 
 void XMesaDestroyContext( XMesaContext c )
 {
+#ifdef FX
+   if (c->FXctx)
+      fxMesaDestroyContext(c->FXctx);
+#endif
    if (c->gl_ctx)
       gl_destroy_context( c->gl_ctx );
    free( c );
@@ -1489,6 +1564,13 @@ XMesaBuffer XMesaCreateWindowBuffer( XMesaVisual v, Window w )
 
    XGetWindowAttributes( v->display, w, &attr );
 
+   if (v->visinfo->depth != attr.depth) {
+      if (getenv("MESA_DEBUG")) {
+         fprintf(stderr, "XMesaCreateWindowBuffer: depth mismatch between visual and window!\n");
+      }
+      return NULL;
+   }
+
    b->xm_visual = v;
    b->pixmap_flag = GL_FALSE;
    b->display = v->display;
@@ -1622,6 +1704,13 @@ GLboolean XMesaMakeCurrent( XMesaContext c, XMesaBuffer b )
    }
 
    if (c) {
+#ifdef FX
+      if (c->FXctx) {
+         fxMesaMakeCurrent(c->FXctx);
+         XMesa = c;
+         return GL_TRUE;
+      }
+#endif
       if (c->gl_ctx == gl_get_current_context() && c->xm_buffer == b
           && c->xm_buffer->wasCurrent) {
          /* same context and buffer, do nothing */
@@ -1687,6 +1776,33 @@ XMesaBuffer XMesaGetCurrentBuffer( void )
 }
 
 
+#ifdef FX
+/*
+ * Read image from VooDoo frame buffer into X/Mesa's back XImage.
+ */
+static void FXgetImage( XMesaBuffer b )
+{
+   int x, y;
+   Window root;
+   unsigned int bw, depth, width, height;
+   assert(XMesa->FXctx);
+   XGetGeometry( XMesa->xm_visual->display, b->frontbuffer,
+                 &root, &x, &y, &width, &height, &bw, &depth);
+   if (b->width != width || b->height != height) {
+      b->width = MIN2(width, FX_WIDTH);
+      b->height = MIN2(height, FX_HEIGHT);
+      if (b->width & 1)  b->width--;  /* prevent odd width */
+      xmesa_alloc_back_buffer( b );
+   }
+
+   grLfbReadRegion( GR_BUFFER_FRONTBUFFER,       /* src buffer */
+                    0, FX_HEIGHT - b->height,    /* position */
+                    b->width, b->height,         /* size */
+                    b->width * sizeof(GLushort), /* stride*/
+                    b->backimage->data);         /* dest buffer */
+}
+#endif
+
 
 /*
  * Copy the back buffer to the front buffer.  If there's no back buffer
@@ -1697,7 +1813,19 @@ void XMesaSwapBuffers( XMesaBuffer b )
 #ifdef PROFILE
    GLdouble t0 = gl_time();
 #endif
+
    if (b->db_state) {
+#ifdef FX
+      if (XMesa->FXctx) {
+         if (XMesa->FXhack) {
+            FXgetImage(b);
+         }
+         else if(XMesa->FXuse) {
+            fxMesaSwapBuffers();
+            return;
+         }
+      }
+#endif
       if (b->backimage) {
 	 /* Copy Ximage from host's memory to server's window */
 #ifdef SHM
@@ -1761,10 +1889,39 @@ GLboolean XMesaGetBackBuffer( XMesaBuffer b, Pixmap *pixmap, XImage **ximage )
 }
 
 
+/*
+ * Return the depth buffer associated with an XMesaBuffer.
+ * Input:  b - the XMesa buffer handle
+ * Output:  width, height - size of buffer in pixels
+ *          bytesPerValue - bytes per depth value (2 or 4)
+ *          buffer - pointer to depth buffer values
+ * Return:  GL_TRUE or GL_FALSE to indicate success or failure.
+ */
+GLboolean XMesaGetDepthBuffer( XMesaBuffer b, GLint *width, GLint *height,
+                               GLint *bytesPerValue, void **buffer )
+{
+   if ((!b->gl_buffer) || (!b->gl_buffer->Depth)) {
+      *width = 0;
+      *height = 0;
+      *bytesPerValue = 0;
+      *buffer = 0;
+      return GL_FALSE;
+   }
+   else {
+      *width = b->gl_buffer->Width;
+      *height = b->gl_buffer->Height;
+      *bytesPerValue = sizeof(GLdepth);
+      *buffer = b->gl_buffer->Depth;
+      return GL_TRUE;
+   }
+}
+
 
 void XMesaFlush( XMesaContext c )
 {
-   XSync( c->xm_visual->display, False );
+   if (c && c->xm_visual) {
+      XSync( c->xm_visual->display, False );
+   }
 }
 
 
@@ -1772,7 +1929,7 @@ void XMesaFlush( XMesaContext c )
 const char *XMesaGetString( XMesaContext c, int name )
 {
    if (name==XMESA_VERSION) {
-      return "2.3";
+      return "2.4";
    }
    else if (name==XMESA_EXTENSIONS) {
       return "";
